@@ -6,10 +6,10 @@ import (
 	"os"
 	"text/template"
 
+	"github.com/k1LoW/errors"
 	"github.com/k1LoW/tbls/config"
 	"github.com/k1LoW/tbls/output"
 	"github.com/k1LoW/tbls/schema"
-	"github.com/pkg/errors"
 )
 
 //go:embed templates/*
